- Moved TCP packet reception to meta handler: less kludgy and less buggy!
[tinc] / src / net.h
index 3dfc3a5..ec88d37 100644 (file)
--- a/src/net.h
+++ b/src/net.h
@@ -15,6 +15,8 @@
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+    $Id: net.h,v 1.9.4.9 2000/08/08 17:07:48 guus Exp $
 */
 
 #ifndef __TINC_NET_H__
 
 #define MAXBUFSIZE 2048 /* Probably way too much, but it must fit every possible request. */
 
+/* flags */
+#define INDIRECTDATA        0x0001 /* Used to indicate that this host has to be reached indirect */
+#define EXPORTINDIRECTDATA  0x0002 /* Used to indicate uplink that it has to tell others to do INDIRECTDATA */
+#define TCPONLY             0x0004 /* Tells sender to send packets over TCP instead of UDP (for firewalls) */
+
 typedef unsigned long ip_t;
 typedef short length_t;
 
@@ -76,7 +83,7 @@ typedef struct status_bits_t {
   int validkey:1;                  /* 1 if we currently have a valid key for him */
   int waitingforkey:1;             /* 1 if we already sent out a request */
   int dataopen:1;                  /* 1 if we have a valid UDP connection open */
-  int unused:22;
+  int unused:21;
 } status_bits_t;
 
 typedef struct queue_element_t {
@@ -100,8 +107,10 @@ typedef struct conn_list_t {
   ip_t vpn_ip;                     /* his vpn ip */
   ip_t vpn_mask;                   /* his vpn network address */
   ip_t real_ip;                    /* his real (internet) ip */
-  char *hostname;                  /* the hostname of its real ip */
+  char *real_hostname;             /* the hostname of its real ip */
+  char *vpn_hostname;              /* the hostname of the vpn ip */
   short unsigned int port;         /* his portnumber */
+  int flags;                       /* his flags */
   int socket;                      /* our udp vpn socket */
   int meta_socket;                 /* our tcp meta socket */
   int protocol_version;            /* used protocol */
@@ -115,6 +124,7 @@ typedef struct conn_list_t {
   char buffer[MAXBUFSIZE+1];       /* metadata input buffer */
   int buflen;                      /* bytes read into buffer */
   int reqlen;                      /* length of first request in buffer */
+  int tcppacket;                  /* length of incoming TCP tunnelled packet */
   time_t last_ping_time;           /* last time we saw some activity from the other end */  
   int want_ping;                   /* 0 if there's no need to check for activity */
   struct conn_list_t *nexthop;     /* nearest meta-hop in this direction */
@@ -138,5 +148,7 @@ extern void main_loop(void);
 extern int setup_vpn_connection(conn_list_t *);
 extern void terminate_connection(conn_list_t *);
 extern void flush_queues(conn_list_t*);
+extern int xrecv(conn_list_t *, void *);
+extern void add_queue(packet_queue_t **, void *, size_t);
 
 #endif /* __TINC_NET_H__ */